@@ -1,7 +1,7 @@
 
 """digitalocean API to manage droplets"""
 
-__version__ = "0.7.1"
+__version__ = "1.0"
 __author__ = "Lorenzo Setale ( http://who.is.lorenzo.setale.me/? )"
 __author_email__ = "koalalorenzo@gmail.com"
 __license__ = "See: http://creativecommons.org/licenses/by-nd/3.0/ "
@@ -12,7 +12,8 @@ from .Droplet import Droplet
 from .Region import Region
 from .Size import Size
 from .Image import Image
-from .Event import Event
+from .Action import Action
 from .Domain import Domain
 from .Record import Record
 from .SSHKey import SSHKey
+from .Kernel import Kernel
\ No newline at end of file
